# Sketch - A Python-based interactive drawing program
# Copyright (C) 2000, 2003 by Bernhard Herzog
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from types import StringType
from string import strip
import gtk
from gtk import FILL, EXPAND

import Sketch
from Sketch import _

from skpanel import SketchPanel


class MetaDataPanel(SketchPanel):

    def __init__(self, context):
        SketchPanel.__init__(self, context, _("MetaData"))
        self.context.Subscribe(Sketch.Base.const.SELECTION,
                               self.context_changed)
        self.context.Subscribe(Sketch.Base.const.TRANSACTION_END,
                               self.context_changed)

    def build_window(self):
        vbox = self.vbox

        table = gtk.Table(2, 2)
        vbox.pack_start(table)

        hadjust = gtk.Adjustment()
        hscrollbar = gtk.HScrollbar(hadjust)
        table.attach(hscrollbar, 0, 1, 1, 2, EXPAND|FILL, 0)
        
        vadjust = gtk.Adjustment()
        vscrollbar = gtk.VScrollbar(vadjust)
        table.attach(vscrollbar, 1, 2, 0, 1, 0, EXPAND|FILL)

        
        self.listbox = gtk.CList(2, (_("Key"), _("Value")))
        self.listbox.set_hadjustment(hadjust)
        self.listbox.set_vadjustment(vadjust)
        self.listbox.connect("select_row", self.list_select)
        self.listbox.connect("unselect_row", self.list_select)
        table.attach(self.listbox, 0, 1, 0, 1, EXPAND|FILL, EXPAND|FILL)

        button = gtk.Button(_("Close"))
        button.connect("clicked", self.close)
        self.action_area.pack_start(button, expand = 0, fill = 0)
       
        table = gtk.Table(2, 3)
        vbox.pack_start(table, expand = 0, fill = 0)

        label = gtk.Label(_("Key"))
        table.attach(label, 0, 1, 0, 1, 0, 0)
        self.key_entry = gtk.Entry()
        table.attach(self.key_entry, 1, 2, 0, 1, EXPAND|FILL, 0)

        label = gtk.Label(_("Value"))
        table.attach(label, 0, 1, 1, 2, 0, 0)
        self.value_entry = gtk.Entry()
        table.attach(self.value_entry, 1, 2, 1, 2, EXPAND|FILL, 0)

        self.eval_check = gtk.CheckButton(_("Value is Python Expression"))
        table.attach(self.eval_check,  0, 2, 2, 3, EXPAND|FILL, 0)

        hbox = gtk.HBox(spacing = 5)
        hbox.set_border_width(5)
        self.vbox.pack_start(hbox, expand = 0, fill = 0)

        button = gtk.Button(_("Add/Set"))
        button.connect("clicked", self.add_data)
        hbox.pack_start(button)
        button = gtk.Button(_("Delete"))
        button.connect("clicked", self.delete_data)
        hbox.pack_start(button)
        
        vbox.show_all()

    def close(self, *args):
        self.context.Unsubscribe(Sketch.Base.const.SELECTION,
                                 self.context_changed)
        self.context.Unsubscribe(Sketch.const.TRANSACTION_END,
                                 self.context_changed)
        SketchPanel.close(self)

    def context_changed(self, *args):
        items = ()
        if self.context.HasEditor():
            obj = self.context.editor.CurrentObject()
            if obj is not None:
                items = obj.DataItems()
                items.sort()
        self.listbox.freeze()
        self.listbox.clear()
        if items:
            for key, value in items:
                row = self.listbox.append((key, repr(value)))
                self.listbox.set_row_data(row, (key, value))
            width = self.listbox.optimal_column_width(0)
            self.listbox.set_column_width(0, width)
        self.listbox.thaw()

    def add_data(self, *args):
        if self.context.HasEditor():
            obj = self.context.editor.CurrentObject()
            if obj is not None:
                key = strip(self.key_entry.get_text())
                if not key:
                    return
                value = self.value_entry.get_text()
                if self.eval_check.get_active():
                    value = eval(value)
                editor = self.context.editor
                editor.CallObjectMethod(Sketch.Graphics.ObjectWithMetaData,
                                        "SetData", (key, value),
                                        title = _("Set Data '%s'") % key)

    def delete_data(self, *args): 
        if self.context.HasEditor():
            obj = self.context.editor.CurrentObject()
            if obj is not None:
                key = strip(self.key_entry.get_text())
                if not key:
                    return
                editor = self.context.editor
                editor.CallObjectMethod(Sketch.Graphics.ObjectWithMetaData,
                                        "DelData", (key,),
                                        title = _("Delete Data '%s'") % key)

    def list_select(self, *args):
        selection = self.listbox.selection
        if selection:
            key, value = self.listbox.get_row_data(selection[0])
            self.key_entry.set_text(key)
            eval = type(value) != StringType
            if eval:
                value = repr(value)
            self.value_entry.set_text(value)
            self.eval_check.set_active(eval)
        else:
            self.key_entry.set_text("")
            self.value_entry.set_text("")
            self.eval_check.set_active(0)
